@@ -60,8 +60,7 @@
 #'  Default is NULL (ignored).
 #' @param tie.breaker An optional permutation of the integers 1 to n used to
 #'  break potential ties in the optimal treatment allocation
-#'  (only relevant if \eqn{\hat \tau(X)} takes on the same values for different samples
-#'  \eqn{X_i} and \eqn{X_j}).
+#'  (only relevant if the predictions \eqn{\hat \tau(X)} are not continuous).
 #'  If NULL, the ties are broken by the lowest sample id (i.e. the sample appearing first in the data).
 #'  Default is NULL.
 #' @param num.threads Number of threads used in bootstrap replicates. By default, the number of threads
@@ -502,18 +501,19 @@ integrated_difference <- function(object.lhs,
   .get_estimate <- function(gain.path, spend.grid, path.idx) {
     if (path.idx == 0) {
       estimate <- 0
-    } else if (abs(spend.grid[length(spend.grid)] - spend) < 1e-10 || path.idx == length(spend.grid)) {
+    } else if (path.idx == length(spend.grid)) {
       area.offset <- 0
       # Are we summing beyond the point at which the curve plateaus?
       if (spend > spend.grid[path.idx]) {
         spend.delta <- spend - spend.grid[path.idx]
-        area.offset <- spend.grid[path.idx] * spend.delta
+        area.offset <- gain.path[path.idx] * spend.delta
       }
       estimate <- mean(gain.path, na.rm = TRUE) + area.offset
     } else {
       interp.ratio <- (spend - spend.grid[path.idx]) / (spend.grid[path.idx + 1] - spend.grid[path.idx])
-      estimate <- mean(gain.path[1:path.idx], na.rm = TRUE) +
-       (gain.path[path.idx + 1] - gain.path[path.idx]) * interp.ratio
+      estimate <- (sum(gain.path[1:path.idx], na.rm = TRUE) +
+          gain.path[path.idx] + (gain.path[path.idx + 1] - gain.path[path.idx]) * interp.ratio) /
+            (path.idx + 1)
     }
 
     estimate
